@@ -257,6 +257,7 @@ pub struct ContainerHostConfig {
     volumes_from: Option<Vec<String>>,
     cap_add: Option<Vec<String>>,
     cap_drop: Option<Vec<String>>,
+    security_opt: Option<Vec<String>>,
     group_add: Option<Vec<String>>,
     restart_policy: Option<RestartPolicy>,
     network_mode: Option<String>,
@@ -269,6 +270,7 @@ pub struct ContainerHostConfig {
     shm_size: Option<u64>,
     userns_mode: Option<String>,
     device_cgroup_rules: Option<Vec<String>>,
+    init: Option<bool>,
 }
 
 impl ContainerHostConfig {
@@ -438,6 +440,11 @@ impl ContainerHostConfig {
         self
     }
 
+    pub fn security_opt(&mut self, security_opt: Vec<String>) -> &mut Self {
+        self.security_opt = Some(security_opt);
+        self
+    }
+
     pub fn group_add(&mut self, group_add: Vec<String>) -> &mut Self {
         self.group_add = Some(group_add);
         self
@@ -492,6 +499,11 @@ impl ContainerHostConfig {
         self.port_bindings = Some(port_bindings);
         self
     }
+
+    pub fn init(&mut self, init: bool) -> &mut Self {
+        self.init = Some(init);
+        self
+    }
 }
 
 #[derive(Debug, Clone, PartialEq, Eq, Serialize, Deserialize)]
@@ -900,6 +912,83 @@ fn test_port_bindings() {
         )
     );
 }
+/// Configuration for container healthchecks.
+#[derive(Debug, Clone, Default, Serialize, Deserialize, PartialEq, Eq)]
+#[serde(rename_all = "PascalCase")]
+pub struct HealthcheckConfig {
+    /// The test to perform. Possible values are:
+    /// - `[]` inherit healthcheck from image or parent image
+    /// - `["NONE"]` disable healthcheck
+    /// - `["CMD", args...]` exec arguments directly
+    /// - `["CMD-SHELL", command]` run command with system's default shell
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub test: Option<Vec<String>>,
+
+    /// The time to wait between checks in nanoseconds. It should be 0 or at least 1_000_000 (1 ms).
+    /// 0 means inherit.
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub interval: Option<u64>,
+
+    /// The time to wait before considering the check to have hung in nanoseconds.
+    /// It should be 0 or at least 1_000_000 (1 ms). 0 means inherit.
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub timeout: Option<u64>,
+
+    /// The number of consecutive failures needed to consider a container as unhealthy.
+    /// 0 means inherit.
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub retries: Option<u8>,
+
+    /// Start period for the container to initialize before starting health-retries countdown in nanoseconds.
+    /// It should be 0 or at least 1_000_000 (1 ms). 0 means inherit.
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub start_period: Option<u64>,
+
+    /// The time to wait between checks in nanoseconds during the start period.
+    /// It should be 0 or at least 1_000_000 (1 ms). 0 means inherit.
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub start_interval: Option<u64>,
+}
+
+impl HealthcheckConfig {
+    /// Creates a new empty HealthConfig.
+    pub fn new() -> Self {
+        Default::default()
+    }
+
+    /// Sets the test command for the healthcheck.
+    pub fn test(&mut self, test: Vec<String>) -> &mut Self {
+        self.test = Some(test);
+        self
+    }
+
+    /// Sets the interval between health checks.
+    /// The duration will be converted to nanoseconds.
+    pub fn interval(&mut self, interval: Duration) -> &mut Self {
+        self.interval = Some(interval.as_nanos() as u64);
+        self
+    }
+
+    /// Sets the timeout for a single health check.
+    /// The duration will be converted to nanoseconds.
+    pub fn timeout(&mut self, timeout: Duration) -> &mut Self {
+        self.timeout = Some(timeout.as_nanos() as u64);
+        self
+    }
+
+    /// Sets the number of retries before marking the container as unhealthy.
+    pub fn retries(&mut self, retries: u8) -> &mut Self {
+        self.retries = Some(retries);
+        self
+    }
+
+    /// Sets the start period for the container. Health checks will not be considered failed during this period.
+    /// The duration will be converted to nanoseconds.
+    pub fn start_period(&mut self, start_period: Duration) -> &mut Self {
+        self.start_period = Some(start_period.as_nanos() as u64);
+        self
+    }
+}
 
 /// request body of /containers/create api
 #[derive(Debug, Clone, Deserialize, Serialize)]
@@ -934,6 +1023,7 @@ pub struct ContainerCreateOptions {
     host_config: Option<ContainerHostConfig>,
     networking_config: Option<NetworkingConfig>,
     exposed_ports: Option<ExposedPorts>,
+    healthcheck: Option<HealthcheckConfig>,
 }
 
 impl ContainerCreateOptions {
@@ -962,6 +1052,7 @@ impl ContainerCreateOptions {
             host_config: None,
             networking_config: None,
             exposed_ports: None,
+            healthcheck: None,
         }
     }
 
@@ -1083,6 +1174,11 @@ impl ContainerCreateOptions {
         self.exposed_ports = Some(exposed_ports);
         self
     }
+
+    pub fn healthcheck(&mut self, healthcheck: HealthcheckConfig) -> &mut Self {
+        self.healthcheck = Some(healthcheck);
+        self
+    }
 }
 
 mod format {
@@ -1240,6 +1336,61 @@ pub struct PrunedImages {
     SpaceReclaimed: i64,
 }
 
+/// Container prune filters
+#[derive(Debug, Clone, PartialEq, Eq, Default)]
+pub struct ContainerPruneFilters {
+    pub until: Vec<String>,
+    pub label: Vec<String>,
+}
+
+impl ContainerPruneFilters {
+    pub fn new() -> Self {
+        Self::default()
+    }
+
+    pub fn is_empty(&self) -> bool {
+        self.until.is_empty() && self.label.is_empty()
+    }
+
+    pub fn until(&mut self, until: String) -> &mut Self {
+        self.until.push(until);
+        self
+    }
+
+    pub fn label(&mut self, label: String) -> &mut Self {
+        self.label.push(label);
+        self
+    }
+}
+
+impl Serialize for ContainerPruneFilters {
+    fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
+    where
+        S: serde::Serializer,
+    {
+        use serde::ser::SerializeMap;
+        let mut map = serializer.serialize_map(None)?;
+
+        if !self.until.is_empty() {
+            map.serialize_entry("until", &self.until)?;
+        }
+        if !self.label.is_empty() {
+            map.serialize_entry("label", &self.label)?;
+        }
+
+        map.end()
+    }
+}
+
+/// Response of the prune containers api
+#[derive(Debug, Clone, PartialEq, PartialOrd, Serialize, Deserialize)]
+#[serde(rename_all = "PascalCase")]
+pub struct PrunedContainers {
+    #[serde(deserialize_with = "null_to_default")]
+    pub containers_deleted: Vec<String>,
+    pub space_reclaimed: i64,
+}
+
 /// Response of the history image api
 #[derive(Debug, Clone, PartialEq, PartialOrd, Serialize, Deserialize)]
 #[serde(rename_all = "PascalCase")]
